@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_AdmFlowDel.php,v 1.7 2007/11/19 14:18:03 seasonstream Exp $
+ * @version   CVS: $Id: SyL_AdmFlowDel.php,v 1.8 2007/12/29 09:15:29 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -44,7 +44,7 @@ require_once SYL_INCLUDE_DIR . '/framework/Adm/SyL_AdmFlow.php';
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_AdmFlowDel.php,v 1.7 2007/11/19 14:18:03 seasonstream Exp $
+ * @version   CVS: $Id: SyL_AdmFlowDel.php,v 1.8 2007/12/29 09:15:29 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_AdmFlowDel extends SyL_AdmFlow
@@ -89,7 +89,7 @@ class SyL_AdmFlowDel extends SyL_AdmFlow
             }
 
             // DB³
-            $conn =& $this->getDB();
+            $conn =& $context->getDB();
             // ADM֥Ⱥ
             $adm  =& SyL_Adm::factory($form, $conn, $keys);
             // ơ֥
@@ -101,11 +101,11 @@ class SyL_AdmFlowDel extends SyL_AdmFlow
             }
             // ¹
             if (!$this->delete($adm)) {
-                $this->closeDB($conn);
+                $context->closeDB($conn);
                 trigger_error("[Adm error] Can't Delete Opperation", E_USER_ERROR);
             }
             // DB³λ
-            $this->closeDB($conn);
+            $context->closeDB($conn);
 
             // λ̤إ쥯
             SyL_Response::redirect($this->getUrl('fin') . '?adm_action=del&adm_u=' . urlencode($data->get('adm_u')));
