@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_AdmFlowLst.php,v 1.8 2007/11/19 14:18:03 seasonstream Exp $
+ * @version   CVS: $Id: SyL_AdmFlowLst.php,v 1.9 2007/12/29 09:15:29 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -44,7 +44,7 @@ require_once SYL_INCLUDE_DIR . '/framework/Adm/SyL_AdmFlow.php';
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_AdmFlowLst.php,v 1.8 2007/11/19 14:18:03 seasonstream Exp $
+ * @version   CVS: $Id: SyL_AdmFlowLst.php,v 1.9 2007/12/29 09:15:29 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_AdmFlowLst extends SyL_AdmFlow
@@ -136,7 +136,7 @@ class SyL_AdmFlowLst extends SyL_AdmFlow
         $form->buildSearch();
 
         // DB³
-        $conn =& $this->getDB();
+        $conn =& $context->getDB();
 
         // ADM֥Ⱥ
         $adm =& SyL_Adm::factory($form, $conn);
@@ -169,7 +169,7 @@ class SyL_AdmFlowLst extends SyL_AdmFlow
         $search_view = $adm->isDefaultSearchView();
 
         // DB³λ
-        $this->closeDB($conn);
+        $context->closeDB($conn);
 
         // ץ饤ޥꥭ
         $primaries    = $adm->getPrimary(false);
