@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_AdmFlowUpd.php,v 1.6 2007/11/19 14:18:03 seasonstream Exp $
+ * @version   CVS: $Id: SyL_AdmFlowUpd.php,v 1.7 2007/12/29 09:15:29 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -44,7 +44,7 @@ require_once SYL_INCLUDE_DIR . '/framework/Adm/SyL_AdmFlow.php';
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_AdmFlowUpd.php,v 1.6 2007/11/19 14:18:03 seasonstream Exp $
+ * @version   CVS: $Id: SyL_AdmFlowUpd.php,v 1.7 2007/12/29 09:15:29 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_AdmFlowUpd extends SyL_AdmFlow
@@ -88,7 +88,7 @@ class SyL_AdmFlowUpd extends SyL_AdmFlow
         }
 
         // DB³
-        $conn =& $this->getDB();
+        $conn =& $context->getDB();
         // ADM֥Ⱥ
         $adm  =& SyL_Adm::factory($form, $conn, array($key));
         // ơ֥
@@ -158,7 +158,7 @@ class SyL_AdmFlowUpd extends SyL_AdmFlow
         $key_value = $adm->getKeyQuery();
 
         // DB³λ
-        $this->closeDB($conn);
+        $context->closeDB($conn);
 
         // եǥǡ
         $data->set('form',      $form->getResultArray());
