@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_AdmOperationLst.php,v 1.6 2007/11/04 13:44:14 seasonstream Exp $
+ * @version   CVS: $Id: SyL_AdmOperationLst.php,v 1.7 2007/11/19 14:18:03 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,11 +39,19 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_AdmOperationLst.php,v 1.6 2007/11/04 13:44:14 seasonstream Exp $
+ * @version   CVS: $Id: SyL_AdmOperationLst.php,v 1.7 2007/11/19 14:18:03 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_AdmOperationLst extends SyL_AdmOperation
 {
+    /**
+     * ץ̾Ѵθ
+     *
+     * @access private
+     * @var array
+     */
+    var $option_values = array();
+
     /**
      * ɽǡ
      *
@@ -64,14 +72,23 @@ class SyL_AdmOperationLst extends SyL_AdmOperation
         // ץDBƤ
         $data_sources = $this->form->getDataSources();
 
-        $tables = array();
         // ơ֥륪֥Ⱥ롼
+        $tables = array();
+        $option_tmp_column = 'ADM_OPTION_COLUMN';
+        $option_tmp_index  = 1;
         foreach (array_keys($this->tables) as $alias) {
             $table =& $this->tables[$alias];
             // ץDBƤ硢ɲäǥå
             foreach ($data_sources as $name => $data_source) {
                 if ($alias == $data_source['alias']) {
-                    $table->addColumn($data_source['name'], $name);
+                    if ($name != $data_source['value']) {
+                        $tmp_option_column = $option_tmp_column . $option_tmp_index++;
+                        $table->addColumn($data_source['value'], $tmp_option_column);
+                        $data_sources[$name]['value'] = $tmp_option_column;
+                    }
+                    $tmp_option_column = $option_tmp_column . $option_tmp_index++;
+                    $table->addColumn($data_source['name'], $tmp_option_column);
+                    $data_sources[$name]['name'] = $tmp_option_column;
                 }
             }
 
@@ -105,6 +122,7 @@ class SyL_AdmOperationLst extends SyL_AdmOperation
             $tables[$alias] =& $table;
         }
 
+
         // ڡ󥻥å
         $this->dao->setPage($page, $limit);
         // ɽǡ
@@ -118,12 +136,24 @@ class SyL_AdmOperationLst extends SyL_AdmOperation
 
         $cnt = count($results);
         for ($i=0; $i<$cnt; $i++) {
+            // ꥪץ̾Ѵ
             foreach ($results[$i] as $name => $value) {
                 if ($options[$name] !== null) {
+                    // ͤ
+                    $this->option_values[$i][$name] = $results[$i][$name];
+                    // ץ̾ѹ
                     $results[$i][$name] = isset($options[$name][$value]) ? $options[$name][$value] : '';
                 }
             }
+            // DBץ̾Ѵ
+            foreach ($data_sources as $name => $data_source) {
+                // ͤ
+                $this->option_values[$i][$name] = $results[$i][$name];
+                // ץ̾ѹ
+                $results[$i][$name] = $results[$i][$data_source['name']];
+            }
         }
+
         return $results;
     }
 
@@ -239,12 +269,15 @@ class SyL_AdmOperationLst extends SyL_AdmOperation
     function getPrimaryLinkParameters(&$results)
     {
         $primary_link_parameters = array();
-        $primaries = $this->getPrimary(true);
+        $primaries = $this->getPrimary(false);
         foreach ($results as $i => $values) {
             $keys = array();
             foreach ($primaries as $name) {
-                $column = substr($name, strpos($name, '.')+1);
-                $keys[$column] = $values[$column];
+                if (isset($this->option_values[$i][$name])) {
+                    $keys[$name] = $this->option_values[$i][$name];
+                } else {
+                    $keys[$name] = $values[$name];
+                }
             }
             $primary_link_parameters[$i] = $this->encodeKey($keys);
         }
