@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_AdmOperationVew.php,v 1.3 2007/10/15 13:56:43 seasonstream Exp $
+ * @version   CVS: $Id: SyL_AdmOperationVew.php,v 1.4 2007/11/19 14:18:03 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_AdmOperationVew.php,v 1.3 2007/10/15 13:56:43 seasonstream Exp $
+ * @version   CVS: $Id: SyL_AdmOperationVew.php,v 1.4 2007/11/19 14:18:03 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_AdmOperationVew extends SyL_AdmOperation
@@ -63,8 +63,12 @@ class SyL_AdmOperationVew extends SyL_AdmOperation
             } else {
                 $table = $this->tables[$data_source['alias']];
             }
+            $table->initDataColumns();
             $table->addColumn($data_source['name']);
             $table->addColumn($data_source['value']);
+            $table->addSort($data_source['name']);
+            $table->addSort($data_source['value']);
+
             // ¸options
             $element_config = $this->form->getConfig($name);
             if (!isset($element_config['options'])) {
