@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_AdmOperation.php,v 1.8 2007/11/19 14:18:03 seasonstream Exp $
+ * @version   CVS: $Id: SyL_AdmOperation.php,v 1.9 2007/12/29 09:15:29 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -48,7 +48,7 @@ require_once SYL_INCLUDE_DIR . '/lib/DB/Dao/SyL_DBDaoTable.php';
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_AdmOperation.php,v 1.8 2007/11/19 14:18:03 seasonstream Exp $
+ * @version   CVS: $Id: SyL_AdmOperation.php,v 1.9 2007/12/29 09:15:29 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_AdmOperation
@@ -137,6 +137,11 @@ class SyL_AdmOperation
                 $this->addRelation($columns);
             }
         }
+
+        // 祭¸ߥå
+        if (count($this->getPrimary()) == 0) {
+            trigger_error("[Adm error] Primary key is required in Adm table object", E_USER_ERROR);
+        }
     }
 
     /**
@@ -159,7 +164,7 @@ class SyL_AdmOperation
                 if (isset($element_config['validate'])) {
                     $element_config['validate'] = array_merge($column_def['validate'], $element_config['validate']);
                 } else {
-                    $element_config['validate'] = array();
+                    $element_config['validate'] = $column_def['validate'];
                 }
                 $this->form->addConfig($column, $element_config);
             }
