@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_AuthFile.php,v 1.5 2007/09/29 09:10:39 seasonstream Exp $
+ * @version   CVS: $Id: SyL_AuthFile.php,v 1.6 2007/11/19 14:18:03 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_AuthFile.php,v 1.5 2007/09/29 09:10:39 seasonstream Exp $
+ * @version   CVS: $Id: SyL_AuthFile.php,v 1.6 2007/11/19 14:18:03 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_AuthFile extends SyL_Auth
@@ -78,7 +78,7 @@ class SyL_AuthFile extends SyL_Auth
             trigger_error("[SyL error] Auth file permission denied ({$passwd_file1})", E_USER_ERROR);
         }
 
-        SyL_Loggers::info("[Auth] Password file: {$passwd_file1}");
+        SyL_Loggers::info("Password file: {$passwd_file1}");
 
         $server_password = null;
         foreach (file($passwd_file1) as $user) {
