@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ConfigActions.php,v 1.24 2007/09/02 14:40:34 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ConfigActions.php,v 1.25 2007/12/29 09:15:29 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -44,7 +44,7 @@ require_once SYL_INCLUDE_DIR . '/framework/SyL_Action.php';
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ConfigActions.php,v 1.24 2007/09/02 14:40:34 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ConfigActions.php,v 1.25 2007/12/29 09:15:29 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ConfigActions extends SyL_Config
@@ -70,13 +70,6 @@ class SyL_ConfigActions extends SyL_Config
      * @var object
      */
     var $action_key = SYL_ACTION_KEY;
-    /**
-     * ǥեȥƥץ졼ȥ
-     * 
-     * @access private
-     * @param string
-     */
-    var $default_template_type = 'default';
     /**
      * ե륭å奭
      * 
@@ -132,10 +125,6 @@ class SyL_ConfigActions extends SyL_Config
         $this->context->setViewType($this->action_cache_value['viewType']);
         // 쥤̾򥻥å
         $this->context->setLayoutName($this->action_cache_value['layoutName']);
-        // ǥեȥƥץ졼Ȥ򥻥å
-        if (isset($this->action_cache_value['template']) && $this->action_cache_value['template']) {
-            $this->context->setTemplateFile($this->action_cache_value['template']);
-        }
     }
 
     /**
@@ -233,15 +222,6 @@ class SyL_ConfigActions extends SyL_Config
                     'viewType'   => isset($attribute['viewType'])   ? $attribute['viewType']   : '', // ӥ塼
                     'layoutName' => isset($attribute['layoutName']) ? $attribute['layoutName'] : ''  // 쥤
                 );
-
-                // ǥեȥƥץ졼ȼ
-                if ((SYL_ENV_TYPE == 'web') && isset($attribute['template'])) {
-                    $template = $attribute['template'];
-                    for ($i=0; $i<count($matches); $i++) {
-                        $template = str_replace("\${$i}", $matches[$i], $template);
-                    }
-                    $this->action_cache_value['template'] = $template;
-                }
             }
             break;
 
