@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ConfigDefines.php,v 1.16 2007/08/27 06:00:04 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ConfigDefines.php,v 1.17 2007/09/29 09:10:39 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ConfigDefines.php,v 1.16 2007/08/27 06:00:04 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ConfigDefines.php,v 1.17 2007/09/29 09:10:39 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ConfigDefines extends SyL_Config
@@ -104,7 +104,7 @@ class SyL_ConfigDefines extends SyL_Config
     function readConstants()
     {
         foreach ($this->config as $key => $value) {
-            $value = preg_replace_callback('/(.*)\{([^\}]+)\}(.*)/', array(&$this, 'replaceConstant'), $value);
+            $value = preg_replace_callback('/\{(\w+)\}/', array(&$this, 'replaceConstant'), $value);
             define($key, $value);
         }
     }
@@ -118,7 +118,7 @@ class SyL_ConfigDefines extends SyL_Config
      */
     function replaceConstant($matches)
     {
-        return defined($matches[2]) ? ($matches[1] . constant($matches[2]) . $matches[3]) : $matches[0];
+        return defined($matches[1]) ? constant($matches[1]) : '{' . $matches[1] . '}';
     }
 }
 
