@@ -49,9 +49,9 @@ function SyL_Ajax()
   this.loadedFunc  = null;
   this.loadingElementId = null;
   this.loadedElementId  = null;
-  this.parameters  = new Array();
-  this.request = this.getXMLHttpObject();
-  this.timeout = 60000;
+  this.parameters  = {};
+  this.request     = this.getXMLHttpObject();
+  this.timeout     = 60000;
 }
 
 SyL_Ajax.prototype = {
@@ -276,19 +276,19 @@ SyL_Ajax.prototype = {
 var SyL_AjaxRequest = {
   sendSyncGet: function(url, action, loadedFunc, loadingFunc, parameters)
   {
-    SyL_AjaxRequest.send(url, action, {loaded: loadedFunc, loading: loadingFunc, async: false, method: 'GET', parameters: parameters});
+    SyL_AjaxRequest.send(url, action, {'loaded': loadedFunc, 'loading': loadingFunc, 'async': false, 'method': 'GET', 'parameters': parameters});
   },
   sendSyncPost: function(url, action, loadedFunc, loadingFunc, parameters)
   {
-    SyL_AjaxRequest.send(url, action, {loaded: loadedFunc, loading: loadingFunc, async: false, method: 'POST', parameters: parameters});
+    SyL_AjaxRequest.send(url, action, {'loaded': loadedFunc, 'loading': loadingFunc, 'async': false, 'method': 'POST', 'parameters': parameters});
   },
   sendAsyncGet: function(url, action, loadedFunc, loadingFunc, parameters)
   {
-    SyL_AjaxRequest.send(url, action, {loaded: loadedFunc, loading: loadingFunc, async: true, method: 'GET', parameters: parameters});
+    SyL_AjaxRequest.send(url, action, {'loaded': loadedFunc, 'loading': loadingFunc, 'async': true, 'method': 'GET', 'parameters': parameters});
   },
   sendAsyncPost: function(url, action, loadedFunc, loadingFunc, parameters)
   {
-    SyL_AjaxRequest.send(url, action, {loaded: loadedFunc, loading: loadingFunc, async: true, method: 'POST', parameters: parameters});
+    SyL_AjaxRequest.send(url, action, {'loaded': loadedFunc, 'loading': loadingFunc, 'async': true, 'method': 'POST', 'parameters': parameters});
   },
 
   /**
@@ -301,21 +301,16 @@ var SyL_AjaxRequest = {
    */
   send: function(url, action, arg)
   {
-    if (!action) {
-      alert('action not found');
-      return;
-    }
-
     if (!url) {
       alert('url undefined');
       return;
     }
 
     var action_key = '<?= $action_key ?>';
-
     var ajax = new SyL_Ajax();
-    ajax.setParameter(action_key, action);
-
+    if (action) {
+        ajax.setParameter(action_key, action);
+    }
     if (typeof(arg) == "object") {
       if (arg.loaded) {
         switch (typeof(arg.loaded)) {
