@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_LoggerHtml.php,v 1.13 2007/05/27 16:24:29 seasonstream Exp $
+ * @version   CVS: $Id: SyL_LoggerHtml.php,v 1.14 2007/09/29 09:10:39 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_LoggerHtml.php,v 1.13 2007/05/27 16:24:29 seasonstream Exp $
+ * @version   CVS: $Id: SyL_LoggerHtml.php,v 1.14 2007/09/29 09:10:39 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_LoggerHtml extends SyL_Logger
@@ -54,7 +54,7 @@ class SyL_LoggerHtml extends SyL_Logger
     function log($level, $message)
     {
         if ($level != '') {
-            $message = sprintf('%s [%s] [%s] %s "%s %s" %s', date($this->datetime_format), SYL_ENV_TYPE, $level, $this->remote_addr, $this->request_method, $this->request_uri, rtrim($message));
+            $message = sprintf('%s [%s] [%s] %s', date($this->datetime_format), SYL_ENV_TYPE, $level, rtrim($message));
         }
         if ($this->immediate || ($level == '')) {
             echo '<font color="CC0000">' . $message . '</font><br>' . $this->eol;
