@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Container.php,v 1.24 2007/11/19 14:18:03 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Container.php,v 1.25 2007/12/29 09:15:29 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -44,7 +44,7 @@ require_once SYL_INCLUDE_DIR . '/framework/SyL_Config.php';
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Container.php,v 1.24 2007/11/19 14:18:03 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Container.php,v 1.25 2007/12/29 09:15:29 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Container
@@ -357,18 +357,21 @@ echo "</pre>";
      */
     function LoadLib($file)
     {
-        if (is_file(SYL_INCLUDE_DIR . "/{$file}")) {
+        if (is_file(SYL_APP_LIB_DIR . "/{$file}")) {
+            // ץꥱ饤֥ǥ쥯ȥ꤫Υѥ
+            include_once SYL_APP_LIB_DIR . "/{$file}";
+        } else if (is_file(SYL_PROJECT_LIB_DIR . "/{$file}")) {
+            // ץȥǥ쥯ȥ꤫Υѥ
+            include_once SYL_PROJECT_LIB_DIR . "/{$file}";
+        } else if (is_file(SYL_INCLUDE_DIR . "/{$file}")) {
             // SyLǥ쥯ȥ꤫Υѥ
             include_once SYL_INCLUDE_DIR . "/{$file}";
-        } else if (is_file(SYL_PROJECT_LIB_DIR . "/{$file}")) {
-            // ץꥱǥ쥯ȥ꤫Υѥ
-            include_once SYL_PROJECT_LIB_DIR . "/{$file}";
         } else if (is_file($file)) {
             // եѥ
             include_once $file;
         } else {
             // ݡͥȥե뤬̵
-            $this->log('info', "Component include failed: file not found (" . SYL_INCLUDE_DIR . "/{$file} or " . SYL_PROJECT_LIB_DIR . "/{$file} or {$file})");
+            $this->log('notice', "Component include failed: file not found (" . SYL_APP_LIB_DIR . "/{$file} or " . SYL_PROJECT_LIB_DIR . "/{$file} or " . SYL_INCLUDE_DIR . "/{$file} or {$file})");
             return false;
         }
         return true;
