@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Context.php,v 1.13 2007/11/19 14:18:03 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Context.php,v 1.14 2007/12/29 09:15:29 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -48,7 +48,7 @@ require_once SYL_INCLUDE_DIR . '/framework/SyL_Loader.php';
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Context.php,v 1.13 2007/11/19 14:18:03 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Context.php,v 1.14 2007/12/29 09:15:29 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Context
@@ -105,7 +105,8 @@ class SyL_Context
     function SyL_Context(&$controller, &$data)
     {
         $this->controller =& $controller;
-        $this->router     =& SyL_Router::factory($data, SYL_ROUTER_RULE);
+        $this->router     =& SyL_Router::factory($controller, $data, SYL_ROUTER_RULE);
+        $this->template_file = $this->router->getTemplateFile();
     }
 
     /**
@@ -135,7 +136,7 @@ class SyL_Context
      */
     function getActionName()
     {
-        return is_object($this->router) ? $this->router->getActionName() : null;
+        return $this->router->getActionName();
     }
 
     /**
@@ -157,7 +158,7 @@ class SyL_Context
      */
     function getActionFile()
     {
-        return is_object($this->router) ? $this->router->getActionFile() : null;
+        return $this->router->getActionFile();
     }
 
     /**
@@ -168,7 +169,7 @@ class SyL_Context
      */
     function getClassName()
     {
-        return is_object($this->router) ? $this->router->getClassName() : null;
+        return $this->router->getClassName();
     }
 
     /**
@@ -316,6 +317,132 @@ class SyL_Context
         return $this->parameters;
     }
 
+    /**
+     * PATH_INFOγURLȤƼ
+     *
+     * @access protected
+     * @param object ƥȥ֥
+     * @return array PATH_INFOγURL
+     */
+    function getUrlNames()
+    {
+        // ǥ쥯ȥ
+        $urls = substr(dirname($this->getActionFile()), 1); // Ƭ/׺
+        return (($urls !== false) && ($urls !== '')) ? explode('/', $urls) : array();
+    }
+
+
+    // -----------------------------------------------------
+    // DBϢ̥᥽å
+    // -----------------------------------------------------
+
+    /**
+     * DB֥Ȥ
+     *
+     * @access protected
+     * @param string DSNʸ
+     * @return object DB֥
+     */
+    function &getDB($dsn='')
+    {
+        static $dsns = array();
+        if (!isset($dsns[$dsn])) {
+            SyL_Loggers::info("getDB for Action");
+            // DB饹󥯥롼
+            include_once SYL_INCLUDE_DIR . '/lib/SyL_DB.php';
+            // DB֥ȼ
+            $dsns[$dsn] =& SyL_DB::getConnection($dsn);
+            $dsns[$dsn]->setCallbackSqlLog(array(__CLASS__, 'addLogDBSql'));
+            $dsns[$dsn]->setCallbackErrorLog(array(__CLASS__, 'addLogDBError'));
+            //register_shutdown_function(array(&$dsns[$dsn], 'closeConnection'));
+        }
+        return $dsns[$dsn];
+    }
+
+    /**
+     * DB֥Ȥ³
+     *
+     * @access protected
+     * @param object DB֥
+     */
+    function closeDB(&$conn)
+    {
+        if (is_object($conn)) {
+            SyL_Loggers::info("DB connection end");
+            $conn->closeConnection();
+            $conn = null;
+        }
+    }
+
+    /**
+     * SQL˵Ͽ
+     *
+     * @static
+     * @access private
+     * @param string å
+     */
+    function addLogDBSql($message)
+    {
+        SyL_Loggers::debug($message);
+    }
+
+    /**
+     * DB顼˵Ͽ
+     *
+     * @static
+     * @access private
+     * @param string å
+     */
+    function addLogDBError($message)
+    {
+        SyL_Loggers::error($message);
+    }
+
+
+    // -----------------------------------------------------
+    // ǧڴϢ̥᥽å
+    // -----------------------------------------------------
+
+    /**
+     * 桼֥Ȥ
+     *
+     * @access protected
+     * @return object 桼֥
+     */
+    function &getUser()
+    {
+        // AUTH饹󥯥롼
+        include_once SYL_INCLUDE_DIR . '/framework/SyL_Auth.php';
+        $auth =& SyL_Auth::singleton();
+        return $auth->getUser();
+    }
+
+    /**
+     * 桼֥Ȥ
+     *
+     * @access protected
+     * @return object 桼֥
+     */
+    function setUser(&$user)
+    {
+        // AUTH饹󥯥롼
+        include_once SYL_INCLUDE_DIR . '/framework/SyL_Auth.php';
+        $auth =& SyL_Auth::singleton();
+        $auth->setUser($user);
+    }
+
+    /**
+     * Ȥ
+     *
+     * @access protected
+     */
+    function doLogout()
+    {
+        // AUTH饹󥯥롼
+        include_once SYL_INCLUDE_DIR . '/framework/SyL_Auth.php';
+        $auth =& SyL_Auth::singleton();
+        $auth->doLogout();
+    }
 }
 
 ?>
