@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Controller.php,v 1.30 2007/11/19 14:18:03 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Controller.php,v 1.31 2007/12/29 09:15:29 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -69,7 +69,7 @@ define('SYL_CONTROLLER_NAME', 'controller');
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Controller.php,v 1.30 2007/11/19 14:18:03 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Controller.php,v 1.31 2007/12/29 09:15:29 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Controller
@@ -338,13 +338,17 @@ class SyL_Controller
         $config_files = array();
         // ץꥱե륿ե
         $filter = SYL_APP_CONFIG_DIR . "/{$this->filter_file_name}";
-        if (file_exists($filter)) {
+        if (is_file($filter)) {
             $config_files['filters'][] = $filter;
+        } else {
+            SyL_Loggers::info("filters app config file not found ({$filter})");
         }
         // Хե륿ե
         $filter = SYL_PROJECT_CONFIG_DIR . "/{$this->filter_file_name}";
         if (file_exists($filter)) {
             $config_files['filters'][] = $filter;
+        } else {
+            SyL_Loggers::info("filters project config file not found ({$filter})");
         }
 
         // ٥ȼ¹
