@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Error.php,v 1.26 2007/11/19 14:18:03 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Error.php,v 1.27 2007/12/29 09:15:29 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Error.php,v 1.26 2007/11/19 14:18:03 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Error.php,v 1.27 2007/12/29 09:15:29 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Error
@@ -398,7 +398,7 @@ class SyL_Error
             $version_php = PHP_VERSION;
             $uname = php_uname();
 
-            $error_mail_subject = "PHP Error occurred - {$server}";
+            $error_mail_subject = "SyL Framework Error Report - {$server} - {$date}";
             $error_mail_body = <<< EOF
 SyL Framework Error info.
 ----------------------------------------
@@ -410,6 +410,10 @@ DATE: {$date}
 SyL Framework ver. {$version} on PHP {$version_php}
 {$uname}
 EOF;
+            // 
+            SyL_Loggers::info("Error mail Subject: " . $error_mail_subject);
+            SyL_Loggers::info("Error mail To: " .      SYL_MAIL_ADMIN_ADDRESS);
+            SyL_Loggers::info("Error mail body\n" .    $error_mail_body);
 
             // 顼᡼¹
             include_once SYL_INCLUDE_DIR . '/lib/SyL_Mail.php';
