@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Logger.php,v 1.14 2007/09/29 09:10:39 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Logger.php,v 1.15 2007/11/19 14:18:03 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Logger.php,v 1.14 2007/09/29 09:10:39 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Logger.php,v 1.15 2007/11/19 14:18:03 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Logger
@@ -150,6 +150,32 @@ class SyL_Logger
         $this->logAll();
     }
 
+    /**
+     * 󥰤Ƥ륯饹᥽åɤ
+     *
+     * @access protected
+     * @return string 󥰤Ƥ륯饹᥽å
+     */
+    function getLoggingClass()
+    {
+        $funcname = '';
+        $match    = false;
+        foreach (debug_backtrace() as $debug) {
+            if (isset($debug['class']) && isset($debug['function'])) {
+                if (preg_match('/^SyL_(Logger|Error)/i', $debug['class']) ||
+                    preg_match('/^(raiseEvent|errorStream)$/i', $debug['function'])) {
+                    $match = true;
+                } else {
+                    $type = isset($debug['type']) ? $debug['type'] : '.';
+                    $funcname = $debug['class'] . $type . $debug['function'] . '()';
+                    if ($match) {
+                        break;
+                    }
+                }
+            }
+        }
+        return $funcname;
+    }
 }
 
 ?>
