@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Loggers.php,v 1.14 2007/11/04 13:44:14 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Loggers.php,v 1.15 2007/11/19 14:18:03 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -44,7 +44,7 @@ require_once 'SyL_Logger.php';
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Loggers.php,v 1.14 2007/11/04 13:44:14 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Loggers.php,v 1.15 2007/11/19 14:18:03 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Loggers
@@ -105,39 +105,39 @@ class SyL_Loggers
         $log =& SyL_Loggers::singleton();
         foreach (array_keys($log->loggers) as $key) {
             if ($log->modes[$key] >= SYL_LOG_ERROR) {
-                $log->loggers[$key]->log('error', $message);
+                $log->loggers[$key]->log('error', $log->formatLog($message));
             }
         }
     }
 
-  /**
-   * νϡWARN
-   *
-   * @access public
-   * @param string å
-   */
-  function warn($message)
-  {
+    /**
+     * νϡWARN
+     *
+     * @access public
+     * @param string å
+     */
+    function warn($message)
+    {
         $log =& SyL_Loggers::singleton();
         foreach (array_keys($log->loggers) as $key) {
             if ($log->modes[$key] >= SYL_LOG_WARN) {
-                $log->loggers[$key]->log('warn', $message);
+                $log->loggers[$key]->log('warn', $log->formatLog($message));
             }
         }
     }
 
-  /**
-   * νϡNOTICE
-   *
-   * @access public
-   * @param string å
-   */
-  function notice($message)
-  {
+    /**
+     * νϡNOTICE
+     *
+     * @access public
+     * @param string å
+     */
+    function notice($message)
+    {
         $log =& SyL_Loggers::singleton();
         foreach (array_keys($log->loggers) as $key) {
             if ($log->modes[$key] >= SYL_LOG_NOTICE) {
-                $log->loggers[$key]->log('notice', $message);
+                $log->loggers[$key]->log('notice', $log->formatLog($message));
             }
         }
     }
@@ -153,7 +153,7 @@ class SyL_Loggers
         $log =& SyL_Loggers::singleton();
         foreach (array_keys($log->loggers) as $key) {
             if ($log->modes[$key] >= SYL_LOG_INFO) {
-                $log->loggers[$key]->log('info', $message);
+                $log->loggers[$key]->log('info', $log->formatLog($message));
             }
         }
     }
@@ -169,7 +169,7 @@ class SyL_Loggers
         $log =& SyL_Loggers::singleton();
         foreach (array_keys($log->loggers) as $key) {
             if ($log->modes[$key] >= SYL_LOG_DEBUG) {
-                $log->loggers[$key]->log('debug', $message);
+                $log->loggers[$key]->log('debug', $log->formatLog($message));
             }
         }
     }
@@ -185,6 +185,26 @@ class SyL_Loggers
             $this->loggers[$key]->close();
         }
     }
+
+    /**
+     * 򷿤ˤäƤѹ
+     *
+     * @access private
+     * @param mixed 
+     * @return string 
+     */
+    function formatLog($message)
+    {
+        if (is_scalar($message)) {
+            if (is_bool($message)) {
+                return $message ? 'true' : 'false';
+            } else {
+                return (string)$message;
+            }
+        } else {
+            return print_r($message, true);
+        }
+    }
 }
 
 ?>
