@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Response.php,v 1.15 2007/09/29 09:10:39 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Response.php,v 1.16 2007/11/19 14:18:03 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Response.php,v 1.15 2007/09/29 09:10:39 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Response.php,v 1.16 2007/11/19 14:18:03 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Response
@@ -129,10 +129,10 @@ class SyL_Response
         if (SYL_ENV_TYPE == 'js') {
             // JSǻѤ硢301 ϥ֥饦٥ǥ쥯Ȥ뤿306
             SyL_Response::setStatusHeader('306');
-            SyL_Loggers::info("[Response] Redirect(306) -> {$url}");
+            SyL_Loggers::info("Redirect(306) -> {$url}");
         } else {
             SyL_Response::setStatusHeader('301');
-            SyL_Loggers::info("[Response] Redirect(301) -> {$url}");
+            SyL_Loggers::info("Redirect(301) -> {$url}");
         }
         SyL_Response::setHeader('Location', $url);
         $obj =& SyL_Response::singleton();
@@ -154,7 +154,7 @@ class SyL_Response
         }
 
         SyL_Response::setStatusHeader('404');
-        SyL_Loggers::info("[Response] 404 Not Found");
+        SyL_Loggers::notice("404 Not Found");
         if (SYL_ENV_TYPE == 'web') {
             include_once SYL_ERROR_FORWARD_FILE_404;
         } else {
@@ -331,7 +331,7 @@ class SyL_Response
                 // ǿMD5ȡʥ֥饦˥åMD5
                 if ($data_new_md5 == $if_none_match) {
                     // ѹʤ
-                    SyL_Loggers::info("[Response] Not Modified(304) Etag: {$data_new_md5}");
+                    SyL_Loggers::info("Not Modified(304) Etag: {$data_new_md5}");
                     SyL_Response::setStatusHeader('304');
                     $this->sendHeader();
                     exit;
@@ -344,7 +344,7 @@ class SyL_Response
                 // ǿMD5ȥåMD5
                 if ($data_new_md5 == $cache->read()) {
                     // ѹʤ
-                    SyL_Loggers::info("[Response] Not Modified(304) Etag: {$data_new_md5}");
+                    SyL_Loggers::info("Not Modified(304) Etag: {$data_new_md5}");
                     SyL_Response::setStatusHeader('304');
                     $this->sendHeader();
                     exit;
