@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Router.php,v 1.16 2007/06/24 10:44:50 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Router.php,v 1.17 2007/12/29 09:15:29 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,11 +39,18 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Router.php,v 1.16 2007/06/24 10:44:50 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Router.php,v 1.17 2007/12/29 09:15:29 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Router
 {
+    /**
+     * 롼ƥե̾
+     * 
+     * @access private
+     * @param string
+     */
+    var $router_file_name = 'routers.xml';
     /**
      * ǥեȥե̾
      * Ƭʸ
@@ -73,6 +80,13 @@ class SyL_Router
      * @var string
      */
     var $action_file = '';
+    /**
+     * ƥץ졼ȥե
+     *
+     * @access protected
+     * @var string
+     */
+    var $template_file = '';
     /**
      * ᥽å̾
      *
@@ -103,16 +117,18 @@ class SyL_Router
      *
      * @static
      * @access public
-     * @param object ꥯȥ֥
+     * @param object ȥ饪֥
+     * @param object ǡ֥
      * @param string ܾ󥪥֥̾
      * @return object ܾ󥪥֥
      */
-    function &factory(&$data, $rule)
+    function &factory(&$controller, &$data, $rule)
     {
         $classname = 'SyL_Router' . ucfirst($rule);
         include_once SYL_INCLUDE_DIR . "/framework/Router/{$classname}.php";
         $router =& new $classname();
         $router->createActionInfo($data);
+        $router->changeRoutingConfig($controller);
         return $router;
     }
 
@@ -130,17 +146,6 @@ class SyL_Router
     {
     }
 
-    /**
-     * ᥽å̾
-     *
-     * @access public
-     * @return string ̾
-     */
-    function getActionName()
-    {
-        return $this->action_method;
-    }
-
     /**
      * ե
      *
@@ -152,17 +157,84 @@ class SyL_Router
         return $this->action_file;
     }
 
+    /**
+     * ƥץ졼ȥե
+     *
+     * @access public
+     * @return string ƥץ졼ȥե
+     */
+    function getTemplateFile()
+    {
+        return $this->template_file;
+    }
+
     /**
      * 饹̾
      *
      * @access public
-     * @return string 饹ե
+     * @return string 饹̾
      */
     function getClassName()
     {
         return $this->action_class;
     }
 
+    /**
+     * ᥽å̾
+     *
+     * @access public
+     * @return string ̾
+     */
+    function getActionName()
+    {
+        return $this->action_method;
+    }
+
+    /**
+     * 롼ƥŬ
+     *
+     * @access protected
+     * @param object ƥȥ֥
+     * @param object ǡ֥
+     */
+    function changeRoutingConfig(&$controller)
+    {
+        $config_files = array();
+        $config_files[] = SYL_APP_CONFIG_DIR . "/{$this->router_file_name}";
+        if (!is_file($config_files[0])) {
+            SyL_Loggers::info("routers config file not found ({$config_files[0]})");
+            return;
+        }
+
+        $config =& SyL_Config::factory('routers', $config_files, $controller);
+        $config->parseXml();
+        foreach ($config->getConfig() as $action => $router) {
+            $action = str_replace('/', '\\/', $action); 
+            if (preg_match('/^(' . $action . ')$/', $this->action_file)) {
+                if ($router['enableAction']) {
+                    $this->action_file  = $router['forwardAction'];
+                    $this->action_class = $this->createActionClass($this->action_file);
+                }
+                if ($router['enableTemplate']) {
+                    $this->template_file = substr($router['forwardAction'], 0, intval('-' . strlen($this->exe_ext))) . SYL_ROUTER_URL_EXT;
+                }
+                break;
+            }
+        }
+    }
+
+    /**
+     * 󥯥饹̾
+     *
+     * @access public
+     * @param string ե
+     * @return string 󥯥饹̾
+     */
+    function createActionClass($action_file)
+    {
+        $classname = str_replace('/', '_', substr($action_file, 1));
+        return preg_replace('/(' . preg_quote($this->exe_ext) . ')$/', '', $classname);
+    }
 }
 
 ?>
