@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_View.php,v 1.25 2007/10/15 13:56:43 seasonstream Exp $
+ * @version   CVS: $Id: SyL_View.php,v 1.26 2007/11/19 14:18:03 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_View.php,v 1.25 2007/10/15 13:56:43 seasonstream Exp $
+ * @version   CVS: $Id: SyL_View.php,v 1.26 2007/11/19 14:18:03 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_View
@@ -130,7 +130,7 @@ class SyL_View
         include_once $classfile;
         $view =& new $classname($context, $data);
 
-        SyL_Loggers::debug("[View] view info env: " . SYL_ENV_TYPE . " type: {$type} class: {$classname} file: {$classfile}");
+        SyL_Loggers::debug("view info env: " . SYL_ENV_TYPE . " type: {$type} class: {$classname} file: {$classfile}");
 
         return $view;
     }
