@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ViewLayoutDefault.php,v 1.6 2007/04/30 13:15:56 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ViewLayoutDefault.php,v 1.7 2007/06/24 10:44:50 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -44,7 +44,7 @@ require_once 'SyL_ViewLayout.php';
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ViewLayoutDefault.php,v 1.6 2007/04/30 13:15:56 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ViewLayoutDefault.php,v 1.7 2007/06/24 10:44:50 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ViewLayoutDefault extends SyL_ViewLayout
@@ -66,11 +66,6 @@ class SyL_ViewLayoutDefault extends SyL_ViewLayout
             }
         }
 
-        // ӥ塼ɽ󥯥롼ɥե
-        foreach ($this->getIncludeFiles() as $include_file) {
-            include_once $include_file;
-        }
-
         // ƥץ졼ȼ
         $template_file = $this->getTemplateDir() . $this->getTemplateFile();
 
@@ -79,6 +74,17 @@ class SyL_ViewLayoutDefault extends SyL_ViewLayout
         include_once $template_file;
         $this->setRender(ob_get_clean());
     }
+
+    /**
+     * 쥤Υƥץ졼Ȥ򥤥󥯥롼ɤ
+     * 
+     * @access public
+     * @param string 쥤Υƥץ졼
+     */
+    function includeTemplate($template)
+    {
+        include $this->getTemplateDir() . $template;
+    }
 }
 
 ?>
