@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_DBDaoTable.php,v 1.6 2007/10/15 13:56:43 seasonstream Exp $
+ * @version   CVS: $Id: SyL_DBDaoTable.php,v 1.7 2007/11/19 14:18:03 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_DBDaoTable.php,v 1.6 2007/10/15 13:56:43 seasonstream Exp $
+ * @version   CVS: $Id: SyL_DBDaoTable.php,v 1.7 2007/11/19 14:18:03 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_DBDaoTable
@@ -166,7 +166,7 @@ class SyL_DBDaoTable
             }
             $this->data_columns[$name] = $value;
         } else {
-            trigger_error("[SyL error] Column name not found in " . get_class($this) . " class ({$name})", E_USER_ERROR);
+            trigger_error("[SyL error] Column name not found in `" . get_class($this) . "' class ({$name})", E_USER_ERROR);
         }
     }
 
