@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_DBDriverMysql.php,v 1.3 2007/07/29 08:54:59 seasonstream Exp $
+ * @version   CVS: $Id: SyL_DBDriverMysql.php,v 1.4 2007/11/04 13:44:14 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_DBDriverMysql.php,v 1.3 2007/07/29 08:54:59 seasonstream Exp $
+ * @version   CVS: $Id: SyL_DBDriverMysql.php,v 1.4 2007/11/04 13:44:14 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_DBDriverMysql extends SyL_DB
@@ -87,11 +87,13 @@ class SyL_DBDriverMysql extends SyL_DB
      */
     function openConnection($dbname, $user, $passwd, $host, $port, $persistent)
     {
-        if ($host == '') $host = 'localhost';
-        if ($port != '') $host .= ':' . $port;
+        $port_tmp = '';
+        if (!$host) $host = 'localhost';
+        if ($port)  $port_tmp = ':' . $port;
 
-        $this->connection = $persistent ? mysql_pconnect($host, $user, $passwd) : mysql_connect($host, $user, $passwd);
+        $this->connection = $persistent ? mysql_pconnect($host . $port_tmp, $user, $passwd) : mysql_connect($host . $port_tmp, $user, $passwd);
         if (is_resource($this->connection) && mysql_select_db($dbname, $this->connection)) {
+            $this->setDsnInfo($dbname, $user, $passwd, $host, $port, $persistent);
             $this->ismore41 = version_compare($this->getVersion(), '4.1.0', '>=');
             return true;
         } else {
