@@ -35,7 +35,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_DBDao.php,v 1.8 2007/11/04 13:44:14 seasonstream Exp $
+ * @version   CVS: $Id: SyL_DBDao.php,v 1.9 2007/12/29 09:15:29 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -56,7 +56,7 @@ require_once 'SyL_DBSqlTableRelations.php';
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_DBDao.php,v 1.8 2007/11/04 13:44:14 seasonstream Exp $
+ * @version   CVS: $Id: SyL_DBDao.php,v 1.9 2007/12/29 09:15:29 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_DBDao
@@ -384,6 +384,72 @@ class SyL_DBDao
         return $result;
     }
 
+    /**
+     * ơ֥쥳ɾ
+     *
+     * @access public
+     * @param object ơ֥륪֥
+     * @param array ѥ᡼
+     * @return array ơ֥쥳ɾ
+     */
+    function getRecord(&$table, $parameters)
+    {
+        $condition = $this->createCondition();
+        foreach ($parameters as $name => $value) {
+            $condition->addEqual($name, $value);
+        }
+        $table->setConditions($condition);
+        $result = $this->select($table);
+        return (count($result) > 0) ? $result[0] : array();
+    }
+
+    /**
+     * ơ֥
+     *
+     * @access public
+     * @param object ơ֥륪֥
+     * @param array ѥ᡼
+     * @param array ȥѥ᡼
+     * @return array ơ֥
+     */
+    function getRecords(&$table, $parameters=array(), $sorts=array())
+    {
+        if (count($parameters) > 0) {
+            $condition = $this->createCondition();
+            foreach ($parameters as $name => $value) {
+                $condition->addEqual($name, $value);
+            }
+            $table->setConditions($condition);
+        }
+        foreach ($sorts as $name) {
+            $table->addSort($name);
+        }
+        return $this->select($table);
+    }
+
+    /**
+     * ơ֥MAX ID
+     *
+     * @access public
+     * @param object ơ֥륪֥
+     * @param string MAX ID
+     * @param array ѥ᡼
+     * @return int MAX ID
+     */
+    function getMaxId(&$table, $column, $parameters=array())
+    {
+        if (count($parameters) > 0) {
+            $condition = $this->createCondition();
+            foreach ($parameters as $name => $value) {
+                $condition->addEqual($name, $value);
+            }
+            $table->setConditions($condition);
+        }
+        $table->addColumn($column, 'MAXID', array('MAX'));
+        $result = $this->select($table);
+        return (count($result) > 0) ? $result[0]['MAXID'] : null;
+    }
+
     /**
      * 祭¸ߥå
      *
