@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Form.php,v 1.14 2007/07/29 08:55:00 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Form.php,v 1.15 2007/12/29 09:15:29 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -48,7 +48,7 @@ require_once 'SyL_Validation.php';
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Form.php,v 1.14 2007/07/29 08:55:00 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Form.php,v 1.15 2007/12/29 09:15:29 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Form
@@ -140,7 +140,6 @@ class SyL_Form
         $this->setAttribute('action', $action ? $action : $_SERVER['PHP_SELF']);
 
         // եॹơ
-        $this->results['form']       = '';
         $this->results['javascript'] = '';
         $this->results['read_only']  = false;
         $this->results['error']      = false;
@@ -177,9 +176,13 @@ class SyL_Form
      *
      * @access public
      * @param object եǥ֥
+     * @param object Хǡ󥪥֥
      */
-    function addElement(&$element)
+    function addElement(&$element, $validation=null)
     {
+        if ($validation != null) {
+            $element->setValidators($validation);
+        }
         if ($element->getType() == 'file') {
             $this->setAttribute('enctype', 'multipart/form-data');
         } else if ($element->getType() == 'group') {
