@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Mail.php,v 1.13 2007/05/27 16:24:29 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Mail.php,v 1.14 2007/12/29 09:15:29 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -52,7 +52,7 @@ if (!defined('SYL_ENCODE_INTERNAL')) {
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Mail.php,v 1.13 2007/05/27 16:24:29 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Mail.php,v 1.14 2007/12/29 09:15:29 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Mail
@@ -165,6 +165,28 @@ class SyL_Mail
         return $mail;
     }
 
+    /**
+     * ᡼륨󥳡ɤ򥻥åȤ
+     *
+     * @access public
+     * @param string ᡼륨󥳡
+     */
+    function setMailEncode($mail_encode)
+    {
+        $this->mail_encode = $mail_encode;
+    }
+
+    /**
+     * ѥ᡼󥳡ɤ򥻥åȤ
+     *
+     * @access public
+     * @param string ѥ᡼󥳡
+     */
+    function setInternalEncode($internal_encode)
+    {
+        $this->internal_encode = $internal_encode;
+    }
+
     /**
      * ɥ쥹򥻥å
      *
@@ -279,7 +301,7 @@ class SyL_Mail
     /**
      * ᡼륢ɥ쥹᡼ʸ˥󥳡ǥ
      * 
-     * @access public
+     * @access private
      * @param string ᡼륢ɥ쥹
      * @param string ᡼륢ɥ쥹̾
      * @return string 󥳡ǥ󥰤Υ᡼륢ɥ쥹
