@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_UtilUseragent.php,v 1.4 2007/09/29 09:10:39 seasonstream Exp $
+ * @version   CVS: $Id: SyL_UtilUseragent.php,v 1.5 2007/12/29 09:15:29 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_UtilUseragent.php,v 1.4 2007/09/29 09:10:39 seasonstream Exp $
+ * @version   CVS: $Id: SyL_UtilUseragent.php,v 1.5 2007/12/29 09:15:29 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_UtilUserAgent
@@ -87,8 +87,10 @@ class SyL_UtilUserAgent
       'hp-ux'           => 'HP-UX',
       'netbsd'          => 'NetBSD',
       'openbsd'         => 'OpenBSD',
+      'Fedora'          => 'Fedora Core',
+      'CentOS'          => 'CentOS',
       'gnu'             => 'GNU/Linux',
-      ' vine'           => 'Vine Linux',
+      'vine'            => 'Vine Linux',
       'linux'           => 'Linux',
       'unix'            => 'Unknown Unix OS',
 
@@ -99,7 +101,7 @@ class SyL_UtilUserAgent
     );
 
     /**
-     * uEUzi}X^j
+     * uEUz
      *
      * @access private
      * @var array
