@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ValidationValidator.php,v 1.4 2007/04/30 13:15:57 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ValidationValidator.php,v 1.5 2007/11/19 14:18:03 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ValidationValidator.php,v 1.4 2007/04/30 13:15:57 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ValidationValidator.php,v 1.5 2007/11/19 14:18:03 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ValidationValidator extends SyL_Validation
@@ -98,12 +98,17 @@ class SyL_ValidationValidator extends SyL_Validation
      * @param string ̾
      * @param string 顼å
      * @param array ڥѥ᡼
+     * @param string Хǡǥ쥯ȥ
      * @return object ̸ڥ֥
      */
-    function &create($type, $error_message, $parameters=array())
+    function &create($type, $error_message, $parameters=array(), $custom_dir='')
     {
-        $classname =  'SyL_ValidationValidator' . ucfirst($type);
-        include_once dirname(__FILE__) . "/Validator/{$classname}.php";
+        $classname = 'SyL_ValidationValidator' . ucfirst($type);
+        if ($custom_dir) {
+            include_once $custom_dir . "/{$classname}.php";
+        } else {
+            include_once dirname(__FILE__) . "/Validator/{$classname}.php";
+        }
         $obj =& new $classname($type, $error_message, $parameters);
         return $obj;
     }
