@@ -5,9 +5,9 @@
  * @access    public
  * @package   {PROJECT_NAME}
  * @author    {author}
- * @version   $Id: Form.php,v 1.2 2007/08/12 05:59:50 seasonstream Exp $
+ * @version   $Id: Form.php,v 1.3 2007/10/15 13:56:43 seasonstream Exp $
  */
-class {FORM_CLASS_NAME} extends SyL_ActionForm
+class {FORM_CLASS_NAME} extends SyL_AdmActionForm
 {
 /**
  * ơ֥륯饹
@@ -30,6 +30,13 @@ var $table_relations = array();
  * @var string
  */
 var $maintenance_table = '{FORM_MAINTENANCE_TABLE}';
+/**
+ * ϢURL
+ * 
+ * @access protected
+ * @var array
+ */
+var $related_links = array();
 /**
  * 
  * 
@@ -53,7 +60,6 @@ var $structs_config = array(
   'enable_vew'          => true,
   'enable_sch'          => true
 );
-
 /**
  * ե
  * 
